#!/bin/bash

DIR=$(realpath $(dirname $0))
if [ ! -z "$1" ]; then
   conf_file=$1
   shift
fi
if [ -z "$1" ]; then
    mode="auto"
else
    mode="$1"
    shift
fi

source $DIR/inc.sh
exec &> >(tee -a "$log_file")

exit_on_fail(){
        [ $1 -ne 0 ] && leave $@
        echo "Done"
}


# Needs to params
#           code=[0-9]+
#           mode="auto|full|inc"
retrie_on_fail(){
    code="$1"
    mode="$2"
    if [ $code -ne 0 ]; then
        keep=$(($BK_KEEP_FULL-1))
        if [ $keep -gt 0 ]; then
            run_duplicity remove-all-inc-of-but-n-full $keep --force
        else
            cat <<EOF | lftp $host
            user $user $ftppass
            glob rm $remotedir/*-inc*
            glob rm $remotedir/*-new-signatures*
EOF
        fi
        backup $mode "cleaned"
        leave $?
    fi
}


#
# Needs to params :
#       mode = "auto|full|inc"
#       retries = "cleaned|"
backup(){
    case $1 in
        "auto")
            action=""
            ;;
        "full")
            action="full"
            ;;
        "inc")
            action="incremental"
            ;;
        "*")
            echo "Unknowkn backup mode '$1'"
            exit 1
    esac
    shift
    retries=$1

    cleanup
    echo "Removing old backups"
    delete_old_backups

    echo "Running pre_actions"
    pre_actions
    exit_on_fail $? "Pre_action failed"
    echo "Creating encrypted $action backup: $bckplist "
    export PASSPHRASE="$encpass"
    export FTP_PASSWORD="$ftppass"
    set -x
    /usr/bin/duplicity $action \
        --verbosity $verbosity \
        --timeout $timeout \
        --full-if-older-than $BK_FULL_FREQ \
        --include ${bckplist// / --include } \
        --exclude /root/.cache/duplicity/ \
        --exclude '**' \
        / \
        $remote
    ret=$?
    set +x
    unset PASSPHRASE
    unset FTP_PASSWORD
    if [ -z "$retries" ]
    then
        retrie_on_fail $ret "Duplicity failed"
    else
        exit_on_fail $ret "Duplicity failed"
    fi

    echo "Backup completed"

    collection_state
    echo "All Done"
}
backup $mode
ret=$?
retrie_on_fail $ret
leave $ret
